<?php
$translations = array(
	'General_Locale' => 'cs_CZ.UTF-8',
	'General_TranslatorName' => 'Filip Bartmann',
	'General_TranslatorEmail' => 'info@joomladev.eu',
	'General_EnglishLanguageName' => 'Czech',
	'General_OriginalLanguageName' => 'Česky',
	'General_HelloUser' => 'Ahoj, %s!',
	'General_OpenSourceWebAnalytics' => 'Open Source Web Analytics',
	'General_Dashboard' => 'Nástěnka',
	'General_DashboardForASpecificWebsite' => 'Nástěnka pro vybrané sídlo',
	'General_MultiSitesSummary' => 'Všechna sídla',
	'General_AllWebsitesDashboard' => 'Nástěnka pro všechna sídla',
	'General_API' => 'API',
	'General_Widgets' => 'Widgety',
	'General_Settings' => 'Nastavení',
	'General_GiveUsYourFeedback' => 'Zanechejte nám zpětnou vazbu!',
	'General_Unknown' => 'Neznámý',
	'General_Never' => 'Nikdy',
	'General_Required' => '%s požadováno',
	'General_NotValid' => '%s není platné',
	'General_NotDefined' => '%s není definováno',
	'General_Id' => 'ID',
	'General_Error' => 'Chyba',
	'General_Warning' => 'Varování',
	'General_BackToHomepage' => 'Zpět na hlavní stránku Piwiku',
	'General_Yes' => 'Ano',
	'General_No' => 'Ne',
	'General_Delete' => 'Vymazat',
	'General_Report' => 'Hlášení',
	'General_Reports' => 'Hlášení',
	'General_Edit' => 'Upravit',
	'General_Download' => 'Stáhnout',
	'General_Upload' => 'Nahrát',
	'General_Ok' => 'OK',
	'General_Close' => 'Zavřít',
	'General_OrCancel' => 'nebo %s Zrušit %s',
	'General_Logout' => 'Odhlásit se',
	'General_Username' => 'Uživatelské jméno',
	'General_Description' => 'Popis',
	'General_Done' => 'Hotovo',
	'General_Name' => 'Jméno',
	'General_Value' => 'Hodnota',
	'General_Total' => 'Celkem',
	'General_PurchasedProducts' => 'Zakoupené produkty',
	'General_EcommerceOrders' => 'Elektronické objednávky',
	'General_AveragePrice' => 'Průměrná cena',
	'General_AverageQuantity' => 'Průměrné množství',
	'General_UniquePurchases' => 'Jedineční nakupující',
	'General_Quantity' => 'Množství',
	'General_Price' => 'Cena',
	'General_Subtotal' => 'Mezisoučet',
	'General_Tax' => 'Daň',
	'General_Discount' => 'Sleva',
	'General_Details' => 'Detaily',
	'General_Default' => 'Výchozí',
	'General_Visit' => 'Návštěva',
	'General_FromReferrer' => 'z',
	'General_VisitorIP' => 'IP návštěvníka',
	'General_VisitType' => 'Typ návštěvníka',
	'General_DaysSinceLastVisit' => 'Dnů od poslední návštěvy',
	'General_DaysSinceFirstVisit' => 'Dnů od první návštěvy',
	'General_DaysSinceLastEcommerceOrder' => 'Dnů od poslední elektronické objednávky',
	'General_NumberOfVisits' => 'Počet návštěv',
	'General_NewVisitor' => 'Nový návštěvník',
	'General_NewVisits' => 'Nové návštěvy',
	'General_Visitor' => 'Návštěvník',
	'General_Date' => 'Datum',
	'General_Period' => 'Období',
	'General_ChooseDate' => 'Vyber datum',
	'General_Today' => 'Dnes',
	'General_Yesterday' => 'Včera',
	'General_CurrentWeek' => 'Tento týden',
	'General_CurrentMonth' => 'Tento měsíc',
	'General_CurrentYear' => 'Tento rok',
	'General_DateRangeFromTo' => 'Od %s do %s',
	'General_DateRangeFrom_js' => 'Od',
	'General_DateRangeTo_js' => 'Do',
	'General_LastDays' => 'Posledních %s dní (včetně dnes)',
	'General_LoadingData' => 'Načítám data...',
	'General_Loading_js' => 'Načítám...',
	'General_GoTo' => 'Jdi na %s',
	'General_Next' => 'Další',
	'General_Previous' => 'Předchozí',
	'General_First' => 'První',
	'General_Search' => 'Hledat',
	'General_Others' => 'Ostatní',
	'General_Table' => 'Tabulka',
	'General_Piechart' => 'Koláčový graf',
	'General_TagCloud' => 'Oblak tagů',
	'General_VBarGraph' => 'Svislý sloupcový graf',
	'General_OpenInNewWindow_js' => 'Otevřít nové okno',
	'General_SaveImageOnYourComputer_js' => 'K uložení obrázku na váš počítač klikněte na obrázek pravým tlačítkem myši a zvolte "Uložit obrázek jako..."',
	'General_Refresh' => 'Obnovit stránku',
	'General_Visitors' => 'Návštěvníci',
	'General_ExportThisReport' => 'Exportovat data v ostatních formátech',
	'General_ExportAsImage_js' => 'Exportovat obrázek',
	'General_Export' => 'Exportovat',
	'General_ParameterMustIntegerBetween' => 'Proměnná %s musí být číselná hodnota mezi %s a %s.',
	'General_YourChangesHaveBeenSaved' => 'Vaše změny byly uloženy',
	'General_ErrorRequest' => 'Jej... během požadavku se vyskytla chyba, prosím zkuste to znovu.',
	'General_ColumnNbUniqVisitors' => 'Jedineční návštěvníci',
	'General_ColumnNbVisits' => 'Návštěv',
	'General_ColumnPercentageVisits' => '% návštěv',
	'General_ColumnNbActions' => 'Akce',
	'General_NbActions' => 'Počet akcí',
	'General_ColumnMaxActions' => 'Maximální počet akcí při jedné návštěvě',
	'General_ColumnSumVisitLength' => 'Celkový čas strávený návštěvníky (v sekundách)',
	'General_ColumnLabel' => 'Popisek',
	'General_ColumnConversionRate' => 'Frekvence konverzí',
	'General_ColumnActionsPerVisit' => 'Akcí za návštěvu',
	'General_VisitDuration' => 'Průměrná doba trvání návštěv (v sekundách)',
	'General_ColumnAvgTimeOnSite' => 'Průměrně času na stránkách',
	'General_ColumnBounceRate' => 'Odchozí frekvence',
	'General_ColumnExitRate' => 'Frekvence odchodů',
	'General_ColumnPageviews' => 'Zobrazení stránek',
	'General_ColumnUniquePageviews' => 'Jedinečná zobrazení stránek',
	'General_ColumnBounces' => 'Ihned odchozí',
	'General_ColumnEntrances' => 'Vstupy',
	'General_ColumnExits' => 'Odchody',
	'General_ColumnAverageTimeOnPage' => 'Přůměrně času na stránce',
	'General_ColumnValuePerVisit' => 'Hodnota za návštěvu',
	'General_ColumnVisitsWithConversions' => 'Návštěvy s přechodem',
	'General_Seconds' => '%s sekund',
	'General_Save' => 'Uložit',
	'General_ForExampleShort' => 'např.',
	'General_YouMustBeLoggedIn' => 'Abyste mohli využívat tyto funkce musíte být přihlášeni',
	'General_Website' => 'Web stránky',
	'General_GeneralSettings' => 'Hlavní nastavení',
	'General_AllowPiwikArchivingToTriggerBrowser' => 'Spouštět archovování když jsou hlášení prohlížena ve Web prohlížeči',
	'General_ArchivingInlineHelp' => 'Pro web stránky se střední, nebo vysokou návštěvností je doporučeno zakázat archivování Piwiku z web prohlížeče. Místo toho doporučujeme vytvoření úlohy pro cron',
	'General_NSeconds' => '%s sekund',
	'General_SmallTrafficYouCanLeaveDefault' => 'Pro sídla s malým provozem můžete ponechat výchozích %s sekund a uvidíte všechna hlášení v reálném čase',
	'General_MediumToHighTrafficItIsRecommendedTo' => 'Pro sídla se středním, nebo velkým provozem doporučujeme zpracovat dnešní hlášení každou půlhodinu (%s vteřin), nebo každou hodinu (%s vteřin)',
	'General_RequiresFlash' => 'Zobrazování grafu v Piwiku vyžaduje Flash',
	'General_GraphHelp' => 'Více informací o zobrazování grafů v Piwiku',
	'General_NoDataForGraph' => 'Pro tento graf nejsou k dispozici žádná data',
	'General_NoDataForTagCloud' => 'Pro tento oblak tagů nejsou k dispozici žádná data.',
	'General_DisplaySimpleTable' => 'Zobrazit jednotuchou tabulku',
	'General_DisplayTableWithMoreMetrics' => 'Zobrazit tabulku s více metrikami',
	'General_DisplayTableWithGoalMetrics' => 'Zobrazit tabulku s metrikou cílů',
	'General_PiwikIsACollaborativeProjectYouCanContribute' => '%s Piwik %s je společný projekt. %s Pokud se Vám líbí, můžete nám pomoct! Prohlédněte si %s Jak přispět do Piwiku?%s',
	'General_YouAreViewingDemoShortMessage' => 'Právě si prohlížíte demoverzi Piwiku',
	'General_NewUpdatePiwikX' => 'Nová aktualizace: Piwik %s',
	'General_AboutPiwikX' => 'O Piwiku %s',
	'General_PiwikXIsAvailablePleaseUpdateNow' => 'Je k dispozici Piwik %s. %s Prosím aktualizujte jej!%s (viz %s změny%s).',
	'General_NewReportsWillBeProcessedByCron' => 'Pokud není archivování spouštěno web prohlížečem budou nová hlášení zpracovávaná cronem',
	'General_ReportsWillBeProcessedAtMostEveryHour' => 'Proto budou hlášení zpracovávaná každou hodinu',
	'General_IfArchivingIsFastYouCanSetupCronRunMoreOften' => 'V případě, že je zálohování dost rychlé, můžete jej spouštět v cronu častěji',
	'General_BackToPiwik' => 'Zpět do Piwiku',
	'General_ShortMonth_1' => 'Led',
	'General_ShortMonth_2' => 'Úno',
	'General_ShortMonth_3' => 'Bře',
	'General_ShortMonth_4' => 'Dub',
	'General_ShortMonth_5' => 'Kvě',
	'General_ShortMonth_6' => 'Čer',
	'General_ShortMonth_7' => 'Čvc',
	'General_ShortMonth_8' => 'Srp',
	'General_ShortMonth_9' => 'Zář',
	'General_ShortMonth_10' => 'Říj',
	'General_ShortMonth_11' => 'Lis',
	'General_ShortMonth_12' => 'Pro',
	'General_LongMonth_1' => 'Leden',
	'General_LongMonth_2' => 'Únor',
	'General_LongMonth_3' => 'Březen',
	'General_LongMonth_4' => 'Duoeb',
	'General_LongMonth_5' => 'Květen',
	'General_LongMonth_6' => 'Červen',
	'General_LongMonth_7' => 'Červenec',
	'General_LongMonth_8' => 'Srpen',
	'General_LongMonth_9' => 'Záři',
	'General_LongMonth_10' => 'Říjen',
	'General_LongMonth_11' => 'Listopad',
	'General_LongMonth_12' => 'Prosinec',
	'General_ShortDay_1' => 'Po',
	'General_ShortDay_2' => 'Út',
	'General_ShortDay_3' => 'St',
	'General_ShortDay_4' => 'Čt',
	'General_ShortDay_5' => 'Pá',
	'General_ShortDay_6' => 'So',
	'General_ShortDay_7' => 'Ne',
	'General_LongDay_1' => 'Pondělí',
	'General_LongDay_2' => 'Úterý',
	'General_LongDay_3' => 'Středa',
	'General_LongDay_4' => 'Čtvrtek',
	'General_LongDay_5' => 'Pátek',
	'General_LongDay_6' => 'Sobota',
	'General_LongDay_7' => 'Neděle',
	'General_Daily' => 'Denně',
	'General_Weekly' => 'Týdně',
	'General_Monthly' => 'Měsíčně',
	'General_ConfigFileIsNotWritable' => 'Konfigurační soubor Piwiku %s není zapisovatelný, některé změny nebudou uloženy. %s Prosím upravte oprávnění ke konfiguračnímu souboru',
	'General_ExceptionDatabaseVersion' => 'Vaše %1$s verze je %2$s ale Piwik vyžaduje minimálně %3$s.',
	'General_ExceptionIncompatibleClientServerVersions' => 'Vaše %1$s verze klienta je %2$s tato je ale nekompatibilní se serverem %3$s.',
	'General_ExceptionMissingFile' => 'Chybějící soubor: %s',
	'General_ExceptionFilesizeMismatch' => 'Nesouhlasí velikost souboru: %1$s (očekávaná délka: %2$s, nalezeno: %3$s)',
	'General_ExceptionFileIntegrity' => 'Test integrity selhal: %s',
	'General_ExceptionNonceMismatch' => 'Nemůžu ověřit bezpečnostní token tohoto formuláře',
	'General_PleaseSpecifyValue' => 'Prosím zapiště hodnotu pro \'%s\'.',
	'General_ExceptionMethodNotFound' => 'Metoda \'%s\' neexistuje nebo není dostupná v modulu \'%s\'.',
	'General_ExceptionInvalidRendererFormat' => 'Formát rendereru \'%s\' není platný. Vyzkoušejte nějaký jiný místo: %s.',
	'General_ExceptionInvalidPeriod' => 'Perioda \'%s\' není podporovaná. Vyzkoušejte nějakou z následujících místo: %s.',
	'General_ExceptionInvalidDateRange' => 'Datum \'%s\' není v platném rozmezí. Může mít následující formát: %s.',
	'General_ExceptionGoalNotFound' => 'Cíl id = %s nenalezen',
	'General_ExceptionUndeletableFile' => 'Nelze vymazat soubor %s',
	'General_ExceptionPrivilege' => 'Nemůžete přistupovat k tomuto zdroji, protože vyžaduje oprávnění %s.',
	'General_ExceptionPrivilegeAtLeastOneWebsite' => 'Nemůžete přistupovat k tomuto zdroji, protože vyžaduje oprávnění %s alespoň pro jedno sídlo',
	'General_ExceptionInvalidArchiveTimeToLive' => 'Dnešní doba života archivu musí být číslo větší než nula',
	'General_ExceptionConfigurationFileNotFound' => 'Konfigurační soubor {%s} nebyl nalezen',
	'General_ExceptionUnreadableFileDisabledMethod' => 'Konfigurační soubor {%s} je nečitelný. Host může být zakázán %s.',
	'General_ExceptionInvalidToken' => 'Token je neplatný',
	'General_ExceptionInvalidDateFormat' => 'Formát data musí být: %s nebo klíčové slovo podporované funkcí %s (více informací viz %s)',
	'General_ExceptionLanguageFileNotFound' => 'Jazykový soubor \'%s\' nenalezen',
	'General_WarningFileIntegritySkipped' => 'Detekováno vývojářské nastavení. Test integrity souboru vynechán',
	'General_WarningFileIntegrityNoManifest' => 'Test integrity nemůže být proveden z důvodů chybějícího souboru manifest.inc.php.',
	'General_WarningFileIntegrityNoMd5file' => 'Test integrity nemůže být dokončen z důvodů chybějící funkce md5_file().',
	'General_FileIntegrityWarningExplanation' => 'Test integrity selhal a nahlásil nějaké chyby. To je díky částečně nebo špatně nahraným souborům Piwiku. Měli byste znova nahrát všechny soubory Piwiku v módu BINARY.',
	'General_UseSMTPServerForEmail' => 'Pro e-mail použít SMTP server',
	'General_SmtpServerAddress' => 'Adresa SMTP serveru',
	'General_SmtpPort' => 'Post SMTP',
	'General_AuthenticationMethodSmtp' => 'Autentizační metoda SMTP',
	'General_SmtpUsername' => 'Uživatelské jméno SMTP',
	'General_SmtpPassword' => 'Heslo SMTP',
	'General_SmtpEncryption' => 'SMTP šifrování',
	'General_SelectYesIfYouWantToSendEmailsViaServer' => 'Zvolte "Ano" pokud chcete e-mail posílat pomocí uvedeného serveru místo lokální funkce PHP mail',
	'General_OnlyUsedIfUserPwdIsSet' => 'Použito pouze v případě, že je nastaveno uživatelské jméno/heslo. V případě že si nejste jisti jakou metodu použít, zeptejte se vašeho poskytovatele',
	'General_OnlyEnterIfRequired' => 'Uživatelské jméno zadejte pouze v případě, že jej váš SMTP server vyžaduje',
	'General_OnlyEnterIfRequiredPassword' => 'Heslo zadejte pouze v případě, že jej váš SMTP server vyžaduje',
	'General_WarningPasswordStored' => '%sUpozornění:%s Toto heslo bude uloženo v konfiguračním souboru viditelné pro všechny s přístupem k němu.',
	'General_InvalidResponse' => 'Obdržená data jsou neplatná.',
	'General_ChooseLanguage' => 'Zvolte jazyk',
	'General_ChoosePeriod' => 'Zvolte období',
	'General_ChooseWebsite' => 'Zvolte sídlo',
	'General_Language' => 'Jazyk',
	'General_PleaseUpdatePiwik' => 'Prosím aktualizujte Piwik',
	'General_RequestTimedOut' => 'Datový požadavek na %s vypršel. Prosím vyzkoušejte jej znovu',
	'Actions_PluginDescription' => 'Hlásí zobrazení stránek, odchozí odkazy a stažení. Zaznamenávání odchozích stránek a stahování je automatické!',
	'Actions_Actions' => 'Akce',
	'Actions_SubmenuPages' => 'Stránky',
	'Actions_SubmenuPagesEntry' => 'Vstupní stránky',
	'Actions_SubmenuPagesExit' => 'Odchozí stránky',
	'Actions_SubmenuPageTitles' => 'Titulky stránek',
	'Actions_SubmenuOutlinks' => 'Odchozí odkazy',
	'Actions_SubmenuDownloads' => 'Stažení',
	'Actions_ColumnClicks' => 'Prokliků',
	'Actions_ColumnUniqueClicks' => 'Unikátních prokliků',
	'Actions_ColumnDownloads' => 'Stažení',
	'Actions_ColumnUniqueDownloads' => 'Unikátních stažení',
	'Actions_ColumnPageName' => 'Jméno stránky',
	'Actions_ColumnPageURL' => 'URL stránky',
	'Actions_ColumnClickedURL' => 'URL prokliku',
	'Actions_ColumnDownloadURL' => 'URL stažení',
	'AnonymizeIP_PluginDescription' => 'Skryje poslední byte IP adresy návštěvníka, aby souhlasila se zákony vaší země.',
	'API_PluginDescription' => 'Všechna data v Piwiku jsou dostupná přes jednoduchá API. Tento plugin je vstupním bodem pro webovou službu, kterou můžete volat abyste získali data ve formátech xml, json, php, csv, atd.',
	'API_QuickDocumentationTitle' => 'Rychlá dokumentace API',
	'API_GenerateVisits' => 'Pokud pro dnešek nemáte data, můžete je nejprve vygenerovat pomocí pluginu %s. Můžete povolit plugin %s a poté kliknout na \'Generátor návštěv\' v menu v administrační části Piwiku',
	'API_MoreInformation' => 'Pro více informací o API Piwiku se podívejte na %s Úvod do API Piwiku %s a %s Referenci API Piwiku %s',
	'API_UserAuthentication' => 'Autentifikace uživatele',
	'API_UsingTokenAuth' => 'Pokud chcete %s načíst data ze skritu, cronu, atd. %s Potřebujete přidat parameter %s k voláním API, které vyžadují příhlášení',
	'API_KeepTokenSecret' => 'Tento token_auth je tajný jako vaše uživatelské jméno a heslo, %s neříkejte jej nikomu jinému %s!',
	'API_LoadedAPIs' => 'Úspěšně načteno %s API',
	'CoreAdminHome_PluginDescription' => 'Administrační část Piwiku',
	'CoreAdminHome_MenuGeneralSettings' => 'Hlavní nastavení',
	'CoreAdminHome_Administration' => 'Administrace',
	'CoreHome_PluginDescription' => 'Struktura hlášení',
	'CoreHome_WebAnalyticsReports' => 'Hlášení',
	'CoreHome_ThereIsNoDataForThisReport' => 'Pro toto hlášení nejsou k dispozici žádná data',
	'CoreHome_CategoryNoData' => 'V této kategorii nejsou k dispozici žádná data. Zkuste "Zobrazit všechny výsledky".',
	'CoreHome_ShowJSCode' => 'Zobrazit JavaScriptový kód ke vložení',
	'CoreHome_PageOf_js' => '%s z %s',
	'CoreHome_PeriodDay' => 'Den',
	'CoreHome_PeriodWeek' => 'Týden',
	'CoreHome_PeriodMonth' => 'Měsíc',
	'CoreHome_PeriodYear' => 'Rok',
	'CoreHome_PeriodDays' => 'dnů',
	'CoreHome_PeriodWeeks' => 'týdnů',
	'CoreHome_PeriodMonths' => 'měsíců',
	'CoreHome_PeriodYears' => 'let',
	'CoreHome_DaySu_js' => 'ne',
	'CoreHome_DayMo_js' => 'po',
	'CoreHome_DayTu_js' => 'út',
	'CoreHome_DayWe_js' => 'st',
	'CoreHome_DayTh_js' => 'čt',
	'CoreHome_DayFr_js' => 'pá',
	'CoreHome_DaySa_js' => 'so',
	'CoreHome_ShortDay_1_js' => 'ne',
	'CoreHome_ShortDay_2_js' => 'po',
	'CoreHome_ShortDay_3_js' => 'út',
	'CoreHome_ShortDay_4_js' => 'st',
	'CoreHome_ShortDay_5_js' => 'čt',
	'CoreHome_ShortDay_6_js' => 'pá',
	'CoreHome_ShortDay_7_js' => 'so',
	'CoreHome_LongDay_1_js' => 'neděle',
	'CoreHome_LongDay_2_js' => 'pondělí',
	'CoreHome_LongDay_3_js' => 'úterý',
	'CoreHome_LongDay_4_js' => 'středa',
	'CoreHome_LongDay_5_js' => 'čtvrtek',
	'CoreHome_LongDay_6_js' => 'pátek',
	'CoreHome_LongDay_7_js' => 'sobota',
	'CoreHome_ShortMonth_1_js' => 'led',
	'CoreHome_ShortMonth_2_js' => 'úno',
	'CoreHome_ShortMonth_3_js' => 'bře',
	'CoreHome_ShortMonth_4_js' => 'dub',
	'CoreHome_ShortMonth_5_js' => 'kvě',
	'CoreHome_ShortMonth_6_js' => 'čer',
	'CoreHome_ShortMonth_7_js' => 'čvc',
	'CoreHome_ShortMonth_8_js' => 'srp',
	'CoreHome_ShortMonth_9_js' => 'zář',
	'CoreHome_ShortMonth_10_js' => 'říj',
	'CoreHome_ShortMonth_11_js' => 'lis',
	'CoreHome_ShortMonth_12_js' => 'pro',
	'CoreHome_MonthJanuary_js' => 'leden',
	'CoreHome_MonthFebruary_js' => 'únor',
	'CoreHome_MonthMarch_js' => 'březen',
	'CoreHome_MonthApril_js' => 'duben',
	'CoreHome_MonthMay_js' => 'květen',
	'CoreHome_MonthJune_js' => 'červen',
	'CoreHome_MonthJuly_js' => 'červenec',
	'CoreHome_MonthAugust_js' => 'srpen',
	'CoreHome_MonthSeptember_js' => 'září',
	'CoreHome_MonthOctober_js' => 'říjen',
	'CoreHome_MonthNovember_js' => 'listopad',
	'CoreHome_MonthDecember_js' => 'prosinec',
	'CorePluginsAdmin_PluginDescription' => 'Administrační rozhraní pluginů',
	'CorePluginsAdmin_Plugins' => 'Pluginy',
	'CorePluginsAdmin_PluginsManagement' => 'Správa pluginů',
	'CorePluginsAdmin_MainDescription' => 'Pluginy rozšiřují funkce Piwiku. Po instalaci pluginu jej můžete povolit nebo zakázat zde.',
	'CorePluginsAdmin_Plugin' => 'Plugin',
	'CorePluginsAdmin_Version' => 'Verze',
	'CorePluginsAdmin_Status' => 'Stav',
	'CorePluginsAdmin_Action' => 'Akce',
	'CorePluginsAdmin_PluginHomepage' => 'Domovká stránka pluginu',
	'CorePluginsAdmin_Activated' => 'Aktivován',
	'CorePluginsAdmin_Active' => 'Povolen',
	'CorePluginsAdmin_Inactive' => 'Zakázán',
	'CorePluginsAdmin_Deactivate' => 'Zakázat',
	'CorePluginsAdmin_Activate' => 'Povolit',
	'CorePluginsAdmin_MenuPlugins' => 'Pluginy',
	'CoreUpdater_PluginDescription' => 'Mechanismus aktualizace Piwiku',
	'CoreUpdater_UpdateTitle' => 'Piwik › Update',
	'CoreUpdater_DatabaseUpgradeRequired' => 'Vyžadováno povýšení databáze',
	'CoreUpdater_YourDatabaseIsOutOfDate' => 'Vaše databáze Piwiku je zastaralá a musí být aktualizována než budete pokračovat.',
	'CoreUpdater_PiwikWillBeUpgradedFromVersionXToVersionY' => 'Databáze Piwiku bude aktualizována z verze %s na novou verzi %s.',
	'CoreUpdater_TheFollowingPluginsWillBeUpgradedX' => 'Následující pluginy budou aktualizovány: %s.',
	'CoreUpdater_NoteForLargePiwikInstances' => 'Důležitá poznámka pro rozsáhlé instalace Piwiku',
	'CoreUpdater_TheUpgradeProcessMayFailExecuteCommand' => 'Pokud máte velkou databázi Piwiku, aktualizace v prohlížeči může trvat dlouhou dobu. V této situaci můžete spustit aktualizaci z příkazového řádku: %s',
	'CoreUpdater_YouCouldManuallyExecuteSqlQueries' => 'Pokud nemůžete použít aktualizaci z příkazového řádku a Piwik nelze aktualizovat (díky vypršení časového limitu v databázi, prohlížeči, nebo z jakéhokoliv jiného důvodu), můžete spustit SQL dotazy ručně',
	'CoreUpdater_ClickHereToViewSqlQueries' => 'Klikněte zde, abyste viděli a zkopírovali SQL dotazy, které mají být spuštěny',
	'CoreUpdater_NoteItIsExpectedThatQueriesFail' => 'Poznámka: Pokud budete SQL dotazy spouštět ručně, některé z nich selžou. V tom případě chyby jednoduše ignorujte a spusťte další dotazy',
	'CoreUpdater_ReadyToGo' => 'Připraven pokračovat?',
	'CoreUpdater_TheUpgradeProcessMayTakeAWhilePleaseBePatient' => 'Aktualizace databáze může chvíli trvat, buďte prosím trpěliví.',
	'CoreUpdater_UpgradePiwik' => 'Aktiualizovat Piwik',
	'CoreUpdater_ErrorDIYHelp' => 'Pokud jste pokročilý uživatel a zaznamenal jste chybu při aktualizaci databáze:',
	'CoreUpdater_ErrorDIYHelp_1' => 'identifikujte problém (např.: memory_limit nebo max_execution_time)',
	'CoreUpdater_ErrorDIYHelp_2' => 'spusťte zbývající dotazy v aktualizaci, která selhala',
	'CoreUpdater_ErrorDIYHelp_3' => 'ručně aktualizujte tabulku `option` ve vaší databázi Piwiku, nastavte hodnotu version_core na verzi selhané aktualizace',
	'CoreUpdater_ErrorDIYHelp_4' => 'abyste dokončili aktualizaci znovu spusťte aktualizaci (přes WWW prohlížeč, nebo příkazovou řádku',
	'CoreUpdater_ErrorDIYHelp_5' => 'nahlašte problém a řešení, aby mohl být Piwik vylepšen',
	'CoreUpdater_HelpMessageContent' => 'Zkontrolujte %s Piwik FAQ %s , který vysvětluje nejčastějsí chybi při aktualizaci. %s Požádejte vašeho systémového administrátora - může vám pomoct s chybou, která je nejčastěji způsobena nastavením serveru MySQL.',
	'CoreUpdater_CriticalErrorDuringTheUpgradeProcess' => 'Při aktualizaci nastala kritická chyba:',
	'CoreUpdater_HelpMessageIntroductionWhenError' => 'Níže je hlavní chybová hláška. Pomůže vám zjistit příčinu,. ale pokud budete potřebovat další pomoc:',
	'CoreUpdater_HelpMessageIntroductionWhenWarning' => 'Aktualizace proběhla v pořádku, ale byly zaznamenány problémy. Prosím přečtěte si nižší popis. Pro další pomoc:',
	'CoreUpdater_UpgradeComplete' => 'Aktualizace je kompletní!',
	'CoreUpdater_WarningMessages' => 'Hlášky upozornění:',
	'CoreUpdater_ErrorDuringPluginsUpdates' => 'Chyba při aktualizací pluginů:',
	'CoreUpdater_WeAutomaticallyDeactivatedTheFollowingPlugins' => 'Automaticky jsme zakázali následující pluginy: %s',
	'CoreUpdater_PiwikHasBeenSuccessfullyUpgraded' => 'Piwik byl úspěšně aktualizován!',
	'CoreUpdater_ContinueToPiwik' => 'Pokračujte do Piwiku',
	'CoreUpdater_UpdateAutomatically' => 'Aktualizovat automaticky',
	'CoreUpdater_ThereIsNewVersionAvailableForUpdate' => 'Je k dispozici nová verze Piwiku',
	'CoreUpdater_YouCanUpgradeAutomaticallyOrDownloadPackage' => 'Můžete aktualizovat na verzi %s automaticky, nebo si stáhněte balíček a nainstalujte jej manuálně:',
	'CoreUpdater_YouMustDownloadPackageOrFixPermissions' => 'Piwik nemůže přepsat Vaší stávající instalaci. Můžete buď opravit oprávnění k adresářům/souborům, nebo stáhnout balíček a nainstalovat verzi %s ručně',
	'CoreUpdater_DownloadX' => 'Stáhnout %s',
	'CoreUpdater_UpdateHasBeenCancelledExplanation' => 'One Click aktualizace Piwiku byla stornována. Pokud nemůžete opravit chybu je doporučeno Piwik aktualizovat manuálně. %s Prosím zkontrolujte pro začátek %sDokumentaci k aktualizaci%s!',
	'CoreUpdater_DownloadingUpdateFromX' => 'Stahuji aktualizaci z %s',
	'CoreUpdater_UnpackingTheUpdate' => 'Rozbaluji aktualizaci',
	'CoreUpdater_VerifyingUnpackedFiles' => 'Ověřuji rozbalené soubory',
	'CoreUpdater_CreatingBackupOfConfigurationFile' => 'Vytvářím zálohu konfiguračního souboru v %s',
	'CoreUpdater_InstallingTheLatestVersion' => 'Instaluji poslední verzi',
	'CoreUpdater_PiwikUpdatedSuccessfully' => 'Piwik úspěšně aktualizován!',
	'CoreUpdater_EmptyDatabaseError' => 'Databáze %s je prázdná. Musíte upravit konfigurační soubor Piwiku, nebo jej vymazat',
	'CoreUpdater_ExceptionAlreadyLatestVersion' => 'Váš Piwik %s již je aktualizován',
	'CoreUpdater_ExceptionArchiveIncompatible' => 'Nekompatibilní archiv: %s',
	'CoreUpdater_ExceptionArchiveEmpty' => 'Archiv je prázdný',
	'CoreUpdater_ExceptionArchiveIncomplete' => 'Archív je nekompletní: některé soubory chybí (např.: %s).',
	'Dashboard_PluginDescription' => 'Váše nástěnka analýzy Web stránek. Můžete si jí upravit: přidat nové widgety, změnit jejich pořadí. Každý uživatel přistupuje ke své vlastní nástěncei',
	'Dashboard_Dashboard' => 'Nástěnka',
	'Dashboard_DeleteWidgetConfirm' => 'Jste si jistí, že chcete odstranit tento widget z nástěnky?',
	'Dashboard_SelectWidget' => 'Zvolte widget pro přidání na nástěnku',
	'Dashboard_AddPreviewedWidget_js' => 'Přidat widget v náhledu na nástěnku',
	'Dashboard_WidgetPreview_js' => 'Náhled widgetu',
	'Dashboard_Close_js' => 'Zavřít',
	'Dashboard_TitleWidgetInDashboard_js' => 'Widget se již nachází na nástěnku',
	'Dashboard_TitleClickToAdd_js' => 'Klikněte k přídání na nástěnku',
	'Dashboard_LoadingWidget_js' => 'Načítám widget, prosím čekejte...',
	'Dashboard_WidgetNotFound_js' => 'Widget nenalezen',
	'DBStats_PluginDescription' => 'Tento plugin hlásí využití databáze MySQL tabulkami Piwiku',
	'DBStats_DatabaseUsage' => 'Využutí databáze',
	'DBStats_MainDescription' => 'Piwik ukládá všechny vaše data webové analýzy v MySQL databázi. Nyní tabulky Piwiku využívají %s.',
	'DBStats_LearnMore' => 'Abyste lépe zjistili, jak Piwik zpracovává data a jak jej nastavit pro sídla se středním a velkým provozem, podívejte se do dokumentace %s.',
	'DBStats_Table' => 'Tabulka',
	'DBStats_RowCount' => 'Počet řádků',
	'DBStats_DataSize' => 'Velikost dat',
	'DBStats_IndexSize' => 'Velikost indexu',
	'DBStats_TotalSize' => 'Celková velikost',
	'ExampleAPI_PluginDescription' => 'Vzorový plugin: Jak vytvořit API pro váš plugin, jak exportovat data v různých formátech bez speciálního kódování?',
	'ExampleFeedburner_PluginDescription' => 'Vzorový plugin: Jak zobrazit data ze služby FeedBurner ve widgetu na tabuli',
	'ExampleRssWidget_PluginDescription' => 'Vzorový plugin: Jak vytvořit nový plugin, který bude číst RSS',
	'ExampleUI_PluginDescription' => 'Vzorový plugin: Tento plugin ukazuje jak pracovat s UI Piwiku: vytváření tabulek, grafů, atd.',
	'Feedback_PluginDescription' => 'Pošlete ohlas teamu Piwiku. Sdílejte s námi vaše nápady a návrhy!',
	'Feedback_DoYouHaveBugReportOrFeatureRequest' => 'Máte hlášení chyby, nebo námět na vylepšení?',
	'Feedback_ViewAnswersToFAQ' => 'Zobrazit odpovědi na %s nejčastěji kladené dotazy %s',
	'Feedback_WhyAreMyVisitsNoTracked' => 'Proč nejsou návštěvy mého sídla zaznamenány?',
	'Feedback_HowToExclude' => 'Jak vyloučím mé návštěvy',
	'Feedback_WhyWrongCountry' => 'Proč Piwik zobrazuje moje návštěvy ze špatné země',
	'Feedback_HowToAnonymizeIP' => 'Jak zamaskovat IP adresu návštěvníka v databázi',
	'Feedback_VisitTheForums' => 'Navštivte %s forum%s',
	'Feedback_LearnWaysToParticipate' => 'Naučit způsoby jak %s spolupracovat %s',
	'Feedback_SpecialRequest' => 'Máte speciální požadavek na tým Piwiku?',
	'Feedback_ContactThePiwikTeam' => 'Kontaktujte tým Piwiku',
	'Feedback_IWantTo' => 'Chci:',
	'Feedback_CategoryShareStory' => 'Sdílet úspěšný příběh Piwiku',
	'Feedback_CategorySponsor' => 'Sponzorovat Piwik',
	'Feedback_CategoryHire' => 'Pronajmout si konzultanta Piwiku',
	'Feedback_CategorySecurity' => 'Nahlásit bezpečnostní problém',
	'Feedback_MyEmailAddress' => 'Moje e-mailová adresa',
	'Feedback_MyMessage' => 'Moje zpráva',
	'Feedback_DetailsPlease' => '(prosím zadejte detaily)',
	'Feedback_SendFeedback' => 'Odeslat odezvu',
	'Feedback_ManuallySendEmailTo' => 'Prosím pošlete ručně zprávu',
	'Feedback_MessageSent' => 'Vaše zpráva byla odeslána týmu Piwiku',
	'Feedback_ThankYou' => 'Děkujeme vám, že pomáháte Piwik dělat lepším',
	'Feedback_ThePiwikTeam' => 'Tým Piwiku',
	'Feedback_ExceptionBodyLength' => 'Zpráva musí být dlouhá alespon %s znaků',
	'Feedback_ExceptionNoUrls' => 'Zpráva nemůže obsahovat URL, aby se zabránilo spamu',
	'Goals_Goals' => 'Cíle',
	'Goals_GoalsOverview' => 'Přehled cílů',
	'Goals_GoalsManagement' => 'Správa cílů',
	'Goals_PluginDescription' => 'Vytvořít cíle a zobrazit hlášení o konverzi cílů: vývoj v čase, příjem za návštěvu, konverze za refereru, klíčové slovo, atd.',
	'Goals_ColumnConversions' => 'Přechody',
	'Goals_ColumnRevenue' => 'Příjem',
	'Goals_GoalX' => 'Cíl: %s',
	'Goals_OverallRevenue' => '%s celkový příjem',
	'Goals_OverallConversionRate' => '%s celková frekvence konverzí (návštěv se splněným cílem)',
	'Goals_Conversions' => '%s konverzí',
	'Goals_ConversionRate' => '%s frekvence konverzí',
	'Goals_NoGoalsNeedAccess' => 'Pouze Administrátor, nebo \'Super Uživatel\' může přidávat cíle pro zadané sídlo. Prosím, zeptejte se vašeho administrátora Piwiku, aby nastavil Cíl pro vaše sídlo.<br />Zaznamenávání cílů je výborná cesta k pochopení a maximalizování výkonu vašoho sídla',
	'Goals_AddNewGoal' => 'Přidat nový cíl',
	'Goals_AddNewGoalOrEditExistingGoal' => '%sPřidat nový cíl%s, nebo %sUpravit%s existující cíle',
	'Goals_AddGoal_js' => 'Přidat cíl',
	'Goals_UpdateGoal_js' => 'Aktualizovat cíl',
	'Goals_DeleteGoalConfirm_js' => 'Jste si jisti, že chcete vymazat tento cíl %s?',
	'Goals_CreateNewGOal' => 'Vytvořit nový cíl',
	'Goals_ViewAndEditGoals' => 'Zobrazit a editovat cíle',
	'Goals_GoalName' => 'Jméno cíle',
	'Goals_GoalIsTriggered' => 'Cíle je zaznamenáván',
	'Goals_GoalIsTriggeredWhen' => 'Cíl je zaznamenáván, když',
	'Goals_WhenVisitors' => 'když návštěvníci',
	'Goals_WhereThe' => 'když',
	'Goals_Manually' => 'ručně',
	'Goals_ManuallyTriggeredUsingJavascriptFunction' => 'Cíl je ručně zaznamenáván pomocí JavaScriptového API trackGoal()',
	'Goals_VisitUrl' => 'Navštívít zadanou URL (stránku, nebo skupiny stránek)',
	'Goals_URL' => 'URL',
	'Goals_Filename' => 'jméno souboru',
	'Goals_ExternalWebsiteUrl' => 'URL externího sídla',
	'Goals_Download' => 'Stáhnout soubor',
	'Goals_ClickOutlink' => 'Kliknout na odkaz na externí sídlo',
	'Goals_Optional' => '(volitelné)',
	'Goals_WhereVisitedPageManuallyCallsJavascriptTrackerLearnMore' => 'kde návštívená stránka obsahuhe volání metody JavaScriptu piwikTracker.trackGoal() (%svíce%s)',
	'Goals_DefaultRevenue' => 'Výchozí příjem cíle je',
	'Goals_DefaultRevenueHelp' => 'Na příklad kontaktní formulář odeslaný návštěvníkem má průměrnou cenu $10. Piwik vám pomůže dobře pochopit chování skupin uživatelů',
	'Goals_ConversionsOverview' => 'Přehled konverzí',
	'Goals_BestCountries' => 'Země s nejvyšším počtem konverzí jsou:',
	'Goals_BestKeywords' => 'Klíčová slova s nejvyšším počtem konverzí jsou:',
	'Goals_BestReferers' => 'Odkazující stránky s nejvyšším počtem konverzí jsou:',
	'Goals_ReturningVisitorsConversionRateIs' => 'Poměr konverze navracejících se uživatelů je %s',
	'Goals_NewVisitorsConversionRateIs' => 'Poměr konverze nové příchozích uživatelů je %s',
	'Goals_Contains' => 'obsahuje %s',
	'Goals_IsExactly' => 'je přesně %s',
	'Goals_MatchesExpression' => 'odpovídá %s',
	'Goals_CaseSensitive' => 'shoda s velikostí písmen',
	'Goals_Pattern' => 'Vzor',
	'Goals_ExceptionInvalidMatchingString' => 'Pokud zvolíte \'přesnou shodu\' odpovídající řetězec musí být URL začínající s %s. Například, \'%s\'.',
	'Goals_LearnMoreAboutGoalTrackingDocumentation' => 'Více o %s Cílech hlášení v Piwiku%s najdete v uživatelské dokumentaci.',
	'Installation_PluginDescription' => 'Instalační proces Piwiku. Instalace se obvykle používá jednou. V případě vymazání konfiguračního souboru config/config.inc.php se instalace zahájí znovu',
	'Installation_Installation' => 'Instalace',
	'Installation_InstallationStatus' => 'Stav instalace',
	'Installation_PercentDone' => '%s %% hotovo',
	'Installation_NoConfigFound' => 'Konfigurační soubor Piwiku nebyl nalezen a snažíte se vstoupit na stránku Piwiku.<br /><b>  » Můžete <a href=\'index.php\'>teď nainstalovat</a></b><br /><small>Pokud jste Piwik již instalovali a máte v DB nějaké tabulky, nemějte obavy. Můžete je použít a zachovat jejich data.!</small>',
	'Installation_DatabaseSetup' => 'Nastavení databáze',
	'Installation_DatabaseSetupServer' => 'server s databází',
	'Installation_DatabaseSetupLogin' => 'uživatelské jméno',
	'Installation_DatabaseSetupPassword' => 'heslo',
	'Installation_DatabaseSetupDatabaseName' => 'jméno databáze',
	'Installation_DatabaseSetupTablePrefix' => 'prefix tabulek',
	'Installation_DatabaseSetupAdapter' => 'adaptér',
	'Installation_DatabaseErrorConnect' => 'Nastala chyba při připojování k databázovému serveru',
	'Installation_DatabaseCheck' => 'Kontrola databáze',
	'Installation_DatabaseServerVersion' => 'Verze databázového serveru',
	'Installation_DatabaseClientVersion' => 'Verze klienta databáze',
	'Installation_DatabaseCreation' => 'Vytvoření databáze',
	'Installation_PleaseFixTheFollowingErrors' => 'Prosím opravte následující chyby',
	'Installation_LargePiwikInstances' => 'Nápověda pro velké instalace Piwiku',
	'Installation_JsTag' => 'JavaScript tag',
	'Installation_JsTagArchivingHelp' => 'Pro sídla se středním a velkým provozem se podívejte na <a target="_blank" href="http://piwik.org/docs/setup-auto-archiving/">Jak nastavit stránku auto archivate</a>, aby Piwik běžel opravdu rychle',
	'Installation_Congratulations' => 'Gratulujeme',
	'Installation_CongratulationsHelp' => '<p>Gratulujeme! Vaše instalace Piwiku je komplentní.</p><p>Ujistěte se, že máte JavaScriptový kód vložen do vašich stránek a čekejte na první návštěvníky!</p>',
	'Installation_ContinueToPiwik' => 'Pokračovat do Piwiku',
	'Installation_SetupWebsite' => 'Nastavit Web sídlo',
	'Installation_SetupWebSiteName' => 'jméno sídla',
	'Installation_SetupWebSiteURL' => 'URL sídla',
	'Installation_Timezone' => 'časová zóna sídla',
	'Installation_SetupWebsiteError' => 'Při přidávání Web sídla se vyskytla chyba',
	'Installation_SetupWebsiteSetupSuccess' => 'Sídlo %s bylo úspěšně vytvořeno',
	'Installation_SuperUserLogin' => 'přihlašovací jméno \'super uživatele\'',
	'Installation_Password' => 'heslo',
	'Installation_PasswordRepeat' => 'heslo (opakování)',
	'Installation_Email' => 'e-mail',
	'Installation_SecurityNewsletter' => 'pošli mi e-mail při hlavních aktualizacích a bezpečnostních oznámeních Piwiku',
	'Installation_CommunityNewsletter' => 'pošli mi e mail s komunitními aktualizacem (nové pluginy, nové funkce, atd.)',
	'Installation_PasswordDoNotMatch' => 'hesla si neodpovídají',
	'Installation_Requirements' => 'Požadavky Piwiku',
	'Installation_Optional' => 'Volitelné',
	'Installation_Legend' => 'Legenda',
	'Installation_Extension' => 'rozšíření',
	'Installation_SystemCheck' => 'Kontrola systému',
	'Installation_SystemCheckPhp' => 'Verze PHP',
	'Installation_SystemCheckExtensions' => 'Další požadovaná rozšíření',
	'Installation_SystemCheckDatabaseHelp' => 'Piwik vyžaduje buď rozšíření mysqli, nebo PDO s pdo_mysql rozšířením',
	'Installation_SystemCheckPhpPdoAndMysqliSite' => 'Více informací na: <a style="color:red" href="http://php.net/pdo">PHP PDO</a> and <a style="color:red" href="http://php.net/mysqli">MYSQLI</a>.',
	'Installation_SystemCheckWinPdoAndMysqliHelp' => 'Na serveru s Winwdows můžete do vašeho php.ini přidat následující řádky: %s',
	'Installation_SystemCheckSplHelp' => 'Musíte překompilovat PHP s povolenou standardní PHP knihovou (ve výchozím stavu povolena).',
	'Installation_SystemCheckZlibHelp' => 'Musíte nakonfigurovat a překompilovat PHP s podporou pro "zlib", --with-zlib',
	'Installation_SystemCheckIconvHelp' => 'Musíte nakonfigurovat a překompilovat PHP s podporou pro "icont", --with-iconv',
	'Installation_SystemCheckWriteDirs' => 'Adresáře s přístupem k zápisu',
	'Installation_SystemCheckWriteDirsHelp' => 'Pro opravu této chyby v Linuxu zkuste napsat následující příkaz(y)',
	'Installation_SystemCheckMemoryLimit' => 'Limit paměti',
	'Installation_SystemCheckMemoryLimitHelp' => 'Na Web sídlech s vysokým provozem, může archivace vyžadovat více paměti něž je nyní povoleno.<br />Pokud je potřeba podívejte se na direktivu memory_limit ve vašem souboru php.ini.',
	'Installation_SystemCheckOpenURL' => 'Otevřít URL',
	'Installation_SystemCheckOpenURLHelp' => 'Předplatné novinek, informace o aktualizaci a aktualizace jedním kliknutím vyžadují rozšíření "curl", allow_url_fopen=On, nebo povolené fsockopen().',
	'Installation_SystemCheckGD' => 'GD > 2.x (graphics)',
	'Installation_SystemCheckGDHelp' => 'Sparkliny (malé grafy) nebudou fungovat.',
	'Installation_SystemCheckFunctions' => 'Vyžadované funkce',
	'Installation_SystemCheckTimeLimitHelp' => 'na Web sídlech s vysokým přenosem, může archivace vyžadovat více času, než je nyní povoleno.<br />Pokud je potřeba podívejte se na direktivu max_execution_time ve vašem souboru php.ini',
	'Installation_SystemCheckMailHelp' => 'Bez funkce mail(), nebudou odeslány zprávy s odezvou, nebo při zapomenutém heslu',
	'Installation_SystemCheckParseIniFileHelp' => 'Tato vestavěná funkce byla na vašem hostiteli zakázaná. Piwik se pokusí tuto funkci emulovat, ale můžete zaznamenat další bezpečnostní omezení. Výkonnost trackeru bude také omezena.',
	'Installation_SystemCheckGlobHelp' => 'Tato vestavěná funkce byla na vašem hostiteli zakázaná. Piwik se pokusí tuto funkci emulovat, ale můžete zaznamenat další bezpečnostní omezení. Toto bude mít vliv na funčnost',
	'Installation_SystemCheckDebugBacktraceHelp' => 'View::factory není schopna vytvořit pohled pro volající modul.',
	'Installation_SystemCheckCreateFunctionHelp' => 'Piwik pro zpětná volání využívá anonymní funkce',
	'Installation_SystemCheckEvalHelp' => 'Vyžadováno šablonovacími systémy HTML QuickForm a Smarty',
	'Installation_SystemCheckMbstring' => 'mbstring',
	'Installation_SystemCheckMbstringExtensionHelp' => 'Rozšíření mbstring je vyžadováno pro multibyte znaky v odezvách API při použití CSV, nebo TSV',
	'Installation_SystemCheckMbstringFuncOverloadHelp' => 'Měli byste nastavit mbstring.func_overload na "0"',
	'Installation_SystemCheckFileIntegrity' => 'Integrita souborů',
	'Installation_SystemCheckAutoUpdateHelp' => 'Poznámla: Aktualizace pomocí jednoho kliknutí vyžaduje práva pro zápis do adresářů Piwiku a jejich obsahu',
	'Installation_SystemCheckError' => 'Vyskytla se chyba - musí být opravena než budete pokračovat',
	'Installation_SystemCheckWarning' => 'Piwik bude pracovat normálně, ale některé funkce budou chybět',
	'Installation_Tables' => 'Vytváření tabulek',
	'Installation_TablesWithSameNamesFound' => 'Některé %s tabulky ve vaší databázi %s mají stejná jména jako tabulky, které se snaží vytvořit Piwik',
	'Installation_TablesFound' => 'V databázi byly nalezeny následující tabulky',
	'Installation_TablesWarningHelp' => 'Vyberte buď použití existujicích tabulek, nebo čistou instalaci, která v databázi smaže existující data.',
	'Installation_TablesReuse' => 'Použít existujicí tabulky',
	'Installation_TablesDelete' => 'Vymazat detekované tabulky',
	'Installation_TablesDeletedSuccess' => 'Existujicí tabulky Piwiku úspěšně vymazány',
	'Installation_TablesCreatedSuccess' => 'Tabulky vytvořeny úspěšně!',
	'Installation_DatabaseCreatedSuccess' => 'Databáze %s vytvořena úspěšně!',
	'Installation_GoBackAndDefinePrefix' => 'Jít zpět a nastavit prefix pro tabulky Piwiku',
	'Installation_ConfirmDeleteExistingTables' => 'Jste si jistí, že chcete vymazat tabulky: %s z vaší databáze? UPOZORNĚNÍ: DATA Z TĚCHTO TABULEK NEPŮJDOU OBNOVIT!',
	'Installation_Welcome' => 'Vítejte!',
	'Installation_WelcomeHelp' => '<p>Piwik je open source program pro analýzu webu, pomocí kterého můžete jednoduše získat informace, které chcete od vaších návštěvníků.</p><p>Tento proces je rozdělen to  %s jednoduchých kroků a zabere přibližne 5 minut.</p>',
	'Installation_ConfigurationHelp' => 'Váš konfigurační soubor Piwiku je špatně nastavený. Můžete buď odstranit soubor config/config.ini a znovu začít instalaci, nebo opravit nastavení databáze.',
	'Installation_ErrorInvalidState' => 'Chyba: zdá se, že se snažíte přeskočit krok instalace, nebo máte zakázány cookies, nebo již je konfigurační soubor Piwiku vytvořen. %sUjistěte se, že máte povoleny cookies%s a vraťte se zpět %s na první stránku instalace %s.',
	'LanguagesManager_PluginDescription' => 'Tento plugin zobrazí seznam jazyků pro rozhraní Piwiku. Vybraný jazyk bude uložen v nastaveních každého uživatele',
	'LanguagesManager_AboutPiwikTranslations' => 'O překladech Piwiku',
	'Live_PluginDescription' => 'Sledujte Vaše uživatele živě v reálném čase',
	'Live_LinkVisitorLog' => 'Zobrazit detailní pohled na návštěvníky',
	'Live_Actions' => 'Akce',
	'Live_Action' => 'Akce',
	'Live_VisitorLog' => 'Pohled na návštěvníky',
	'Live_Time' => 'Čas',
	'Live_Referrer_URL' => 'Odkazující URL',
	'Live_GoalType' => 'Typ',
	'Live_GoalTime' => 'První čas konverze',
	'Live_GoalRevenue' => 'Výnos',
	'Live_GoalDetails' => 'Detaily',
	'Login_PluginDescription' => 'Plugin pro autentifikaci přihlášením. Přihlašovací údaje čte pro \'Super Uživatele\' z config/config.ini a pro ostetní uživatelé z databáze. Pro nový autentizační mechanizmus(OpenID, htaccess, vlastní autentifikace, atd.) může být jednoduše vyměněn.',
	'Login_LoginPasswordNotCorrect' => 'Uživatelské jméno & heslo nejsou správné',
	'Login_Password' => 'Heslo',
	'Login_PasswordRepeat' => 'Heslo (pro kontrolu)',
	'Login_ChangePassword' => 'Změnit heslo',
	'Login_LoginOrEmail' => 'Uživatelské jméno nebo E-mail',
	'Login_LogIn' => 'Přihlásit',
	'Login_Logout' => 'Odhlásit',
	'Login_LostYourPassword' => 'Zapomněli jste vaše heslo?',
	'Login_RemindPassword' => 'Připomenout heslo',
	'Login_PasswordResetToken' => 'Token pro změnu hesla',
	'Login_PasswordReminder' => 'Prosím zadejte vaše uživatelské jméno, nebo e-mailovou adresu. Nové heslo dostanete e-mailem.',
	'Login_PasswordsDoNotMatch' => 'Hesla si neodpovídají',
	'Login_PasswordSuccessfullyChanged' => 'Heslo bylo úspěšně změněno',
	'Login_InvalidUsernameEmail' => 'Neplatné uživatelské jméno a/nebo e-mailová adresa',
	'Login_InvalidOrExpiredToken' => 'Klíč je neplatný, nebo vypršel',
	'Login_MailTopicPasswordRecovery' => 'Záchrana hesla',
	'Login_MailPasswordRecoveryBody' => 'Ahoj %1$s,

A požadavek na reset hesla byl obdržen z %2$s.

Ke změně hesla:

1) Jdi na formulář pro reset hesla na:
	%3$s

2) Volžte následující klíč:
	%4$s

3) Vyplňte formulář(zadejte vaše nové heslo dvakrát) a odešlete jej.

Poznámka: tento klíč expiruje za 24 hodin.',
	'Login_PasswordSent' => 'Heslo bylo právě odesláno. Zkontrolujte si váš e-mail.',
	'Login_ContactAdmin' => 'Možná příčina: Váš hosting zakázal funkci mail().. <br />Prosím kontaktujte vašeho administrátora Piwiku.',
	'Login_ExceptionPasswordMD5HashExpected' => 'Parametr hesla je očekáván jako MD5 hash hesla',
	'Login_ExceptionInvalidSuperUserAuthenticationMethod' => '\'Super uživatel\' nemůže být přihlášení pomocí mechanismu  \'%s\'',
	'Mobile_AnonymousAccess' => 'Anonymní přístup',
	'Mobile_AccessUrlLabel' => 'Přístupová URL Piwiku',
	'Mobile_EnableGraphsLabel' => 'Zobrazit grafy',
	'Mobile_MultiChartLabel' => 'Zobrazit multi grafy',
	'Mobile_NetworkNotReachable' => 'Síť je nedosažitelná',
	'Mobile_SaveSuccessError' => 'Prosím zkontrolujte si vaše nastavení',
	'Mobile_YouAreOffline' => 'Omlouváme se, momentálně jste offline',
	'MultiSites_PluginDescription' => 'Zobrazí souhrn/statistiky pro více sídel. Současně je spravován jako jaderný plugin Piwiku',
	'MultiSites_Evolution' => 'Vývoj',
	'Provider_PluginDescription' => 'Zobrazí poskytovatele připojení návštěvníků',
	'Provider_WidgetProviders' => 'Poskytovatelé',
	'Provider_ColumnProvider' => 'Poskytovatel',
	'Provider_SubmenuLocationsProvider' => 'Umístění a poskytovatel',
	'Referers_PluginDescription' => 'Zobrazí data refererů: vyhledávací stroje, klíčová slova, webová sídla, správu kampaní, přímé vstupy',
	'Referers_Referers' => 'Odkazující stránky',
	'Referers_SearchEngines' => 'Vyhledávacích strojů',
	'Referers_Keywords' => 'Klíčových slov',
	'Referers_DirectEntry' => 'Přímy vstup',
	'Referers_Websites' => 'Web sídla',
	'Referers_Campaigns' => 'Kampaně',
	'Referers_Evolution' => 'Vývoj za periodu',
	'Referers_Type' => 'Typ refereru',
	'Referers_ColumnRefererType' => 'Typ refereru',
	'Referers_ColumnSearchEngine' => 'Vyhledávací stroj',
	'Referers_ColumnWebsite' => 'Web sídlo',
	'Referers_ColumnWebsitePage' => 'Web stránka',
	'Referers_ColumnKeyword' => 'Klíčové slovo',
	'Referers_ColumnCampaign' => 'Kampaň',
	'Referers_DetailsByRefererType' => 'Podrobnosti podle typu refereru',
	'Referers_TypeDirectEntries' => '%s přímých vstupů',
	'Referers_TypeSearchEngines' => '%s z vyhledavačů',
	'Referers_TypeWebsites' => '%s z web sídel',
	'Referers_TypeCampaigns' => '%s z kampaní',
	'Referers_Distinct' => 'Jedineční refereři podle typu',
	'Referers_DistinctSearchEngines' => 'jedinečné vyhledávače',
	'Referers_DistinctKeywords' => 'jedinečná klíčová slova',
	'Referers_DistinctCampaigns' => 'jedinečné kampaně',
	'Referers_DistinctWebsites' => 'jedinečná webová sídla',
	'Referers_UsingNDistinctUrls' => '(používá %s jedinečných url)',
	'Referers_SubmenuSearchEngines' => 'Vyhledávače & klíčová slova',
	'Referers_SubmenuWebsites' => 'Web sídla',
	'Referers_SubmenuCampaigns' => 'Kampaně',
	'Referers_WidgetKeywords' => 'Seznam klíčových slov',
	'Referers_WidgetCampaigns' => 'Seznam kampaní',
	'Referers_WidgetExternalWebsites' => 'Seznam externích web sídel',
	'Referers_WidgetSearchEngines' => 'Nejlepší vyhledávače',
	'Referers_WidgetOverview' => 'Přehled',
	'SecurityInfo_PluginDescription' => 'Založeno na PhpSecInfo od PHP Security Consorcium. Tento plugin poskytuje informace o zabezpečení prostředí PHP a nabízí rady na vylepšení. Jedná se o nástroj pro vícevrstvé přiblížení se bezpečnosti. Nepoužívejte jej místo bezpečných praktit vývoje, nebo auditu kódu/aplikace.',
	'SecurityInfo_Security' => 'Zabezpečení',
	'SecurityInfo_SecurityInformation' => 'Informace o zabezpečení PHP',
	'SecurityInfo_Test' => 'Test',
	'SecurityInfo_Result' => 'Výsledek',
	'SEO_SeoRankings' => 'Hodnocení SEO',
	'SEO_AlexaRank' => 'Hodnocení Alexa',
	'SEO_DomainAge' => 'Staří domény',
	'SEO_Rank' => 'Hodnocení',
	'SEO_Backlinks' => 'Zpětné odkazy',
	'SEO_Pages' => 'Stránky',
	'SEO_SEORankingsFor' => 'SEO hodnocení pro %s',
	'SitesManager_PluginDescription' => 'Správa sídel v Piwiku: Přidat nové sídlo, Upravit existující, Zobrazit JavaScriptový kód při umístění na stránky. Všechny akce jsou k dispozici také přes API.',
	'SitesManager_Sites' => 'Web sídla',
	'SitesManager_TrackingTags' => 'Zaznamenávací tagy pro %s',
	'SitesManager_WebsitesManagement' => 'Nastavení Web sídel',
	'SitesManager_MainDescription' => 'Vaše analýzy webu potřebují Web sídla! Přidejte, aktualizujte, nebo vymažte je a zobrazte si JavaScriptový kód pro vložení do vaších stránek.',
	'SitesManager_JsTrackingTag' => 'JavaScriptový zaznamenávací tag',
	'SitesManager_JsTrackingTagHelp' => 'Zde je JavaScriptový zaznamenávací tag pro vložení na všechny vaše stránky',
	'SitesManager_ShowTrackingTag' => 'zobrazit zaznamenávací tagy',
	'SitesManager_NoWebsites' => 'Nemáte žádné Web sídlo k administraci.',
	'SitesManager_AddSite' => 'Přídat nové sídlo',
	'SitesManager_NotFound' => 'Zádné www sídla nenalezený pro',
	'SitesManager_AliasUrlHelp' => 'Je doporučeno, ale ne vyžadováno, specifikovat různé URL, jednu na řádku, které vaší návštěvníci používají pro přístup ke stránkám.  Aliasy se neobjeví hlášení Odkazující stránky>WWW sídla.  Všimněte si, že není nutné zadávat URL s a bez \'www\'. Piwik automaticky rozezná obě.',
	'SitesManager_Urls' => 'URL',
	'SitesManager_MenuSites' => 'Sídla',
	'SitesManager_DeleteConfirm_js' => 'Jste si jisti, že chcete vymazat Web sídlo %s?',
	'SitesManager_ExceptionDeleteSite' => 'Není možné vymazat toto Web sídlo, protože je jediné registrované. Nejprve přidejte nové sídlo, poté jej vymažte.',
	'SitesManager_ExceptionNoUrl' => 'Musíte zadat alespoň jednu URL pro sídlo.',
	'SitesManager_ExceptionEmptyName' => 'Jméno Web sídla nemůže zůstat prázdné.',
	'SitesManager_ExceptionInvalidUrl' => 'URL \'%s\' není platné URL.',
	'SitesManager_ExceptionInvalidTimezone' => 'Časová zóna %s je neplatná. Prozím zadejte platnou zónu.',
	'SitesManager_ExceptionInvalidCurrency' => 'Měna %s je neplatná. Prosím zadejte platný symbol měny. (např.: %s)',
	'SitesManager_ExceptionInvalidIPFormat' => 'IP adresa k vynechání "%s" není v platném formátu (např.: %s)',
	'SitesManager_SuperUserCan' => '\'Super uživatel\' může také %s speficikovat globální nastavení %s pro nová sídla.',
	'SitesManager_ExcludedIps' => 'Vynechané IP adresy',
	'SitesManager_GlobalListExcludedIps' => 'Globální seznam vynechaných IP adres',
	'SitesManager_ListOfIpsToBeExcludedOnAllWebsites' => 'IP adresy uvedené níže budou vynechány ze záznamu pro všechna web sídla.',
	'SitesManager_ExcludedParameters' => 'Vynechané parakmetry',
	'SitesManager_GlobalListExcludedQueryParameters' => 'Globální seznam vynechaných URL parametrů',
	'SitesManager_ListOfQueryParametersToBeExcludedOnAllWebsites' => 'URL parametry uvedené níže budou vynechány z URL pro všecna www sídla',
	'SitesManager_ListOfQueryParametersToExclude' => 'Zadejte seznam URL parametrů, jeden na řádek, které budou vynechány z hlášení Piwiku',
	'SitesManager_PiwikWillAutomaticallyExcludeCommonSessionParameters' => 'Piwik automaticky vynechá běžné parametry sezení (%s)',
	'SitesManager_HelpExcludedIps' => 'Zatejte seznam IP adrese, jednu na řádek, které chcete vynechat ze záznamů Piwiku. Můžete použít zástupné znaky např. %1$s nebo %2$s',
	'SitesManager_YourCurrentIpAddressIs' => 'Vaše současná IP adresa je %s',
	'SitesManager_SelectACity' => 'Zvolte město',
	'SitesManager_ChooseCityInSameTimezoneAsYou' => 'Zvolte město ve stejné časové zóně jako se nacházíte vy',
	'SitesManager_ChangingYourTimezoneWillOnlyAffectDataForward' => 'Změna vaší časové zóny se projeví pouze v nových datech a nebude aplikována zpětně.',
	'SitesManager_AdvancedTimezoneSupportNotFound' => 'Pokročilá podpora časových zón nebyla ve vašem PHP (podporována v PHP >=5.2) nalezena. Stále můžete použít ruční UTF offset.',
	'SitesManager_UTCTimeIs' => 'UTC čas je %s',
	'SitesManager_Timezone' => 'Časová zóna',
	'SitesManager_GlobalWebsitesSettings' => 'Globální nastavení sídel',
	'SitesManager_DefaultTimezoneForNewWebsites' => 'Výchozí časová zóna pro nová sídla',
	'SitesManager_SelectDefaultTimezone' => 'Můžete zvolit výchozí časovou zónu pro nová sídla',
	'SitesManager_Currency' => 'Měna',
	'SitesManager_CurrencySymbolWillBeUsedForGoals' => 'Symbol měny bude zobrazen vedle příjmů z cílů.',
	'SitesManager_DefaultCurrencyForNewWebsites' => 'Výchozí měna pro nová sídla',
	'SitesManager_SelectDefaultCurrency' => 'Můžete zvolit výchozí měnu pro nová sídla',
	'TranslationsAdmin_PluginDescription' => 'Pomožte přeložit Piwik do Vašeho jazyka',
	'TranslationsAdmin_MenuTranslations' => 'Překlady',
	'TranslationsAdmin_MenuLanguages' => 'Jazyky',
	'TranslationsAdmin_LanguageCode' => 'Jazykový kód',
	'TranslationsAdmin_Plugin' => 'Plugin',
	'TranslationsAdmin_Definition' => 'Definice',
	'TranslationsAdmin_DefaultString' => 'Výchozí jazyk (Anglicky)',
	'TranslationsAdmin_TranslationString' => 'Překladový řetězec (aktuální jazyk: %s)',
	'TranslationsAdmin_Translations' => 'Překlady',
	'TranslationsAdmin_FixPermissions' => 'Prosím opravte oprávnění souborového systému',
	'TranslationsAdmin_AddLanguage' => 'Přidat jazyk',
	'TranslationsAdmin_Export' => 'Exportovat jazyk',
	'TranslationsAdmin_Import' => 'Importovat jazyk',
	'UserCountry_PluginDescription' => 'Zobrazí státy návštěvníků',
	'UserCountry_Country' => 'Státy',
	'UserCountry_Continent' => 'Kontinent',
	'UserCountry_DistinctCountries' => '%s jedinečných států',
	'UserCountry_Location' => 'Místo',
	'UserCountry_SubmenuLocations' => 'Umístění',
	'UserCountry_WidgetContinents' => 'Kontinenty návštěvníků',
	'UserCountry_WidgetCountries' => 'Státy návštěvníků',
	'UserCountry_country_ac' => 'Ascension Islands',
	'UserCountry_country_ad' => 'Andorra',
	'UserCountry_country_ae' => 'United Arab Emirates',
	'UserCountry_country_af' => 'Afghanistan',
	'UserCountry_country_ag' => 'Antigua and Barbuda',
	'UserCountry_country_ai' => 'Anguilla',
	'UserCountry_country_al' => 'Albania',
	'UserCountry_country_am' => 'Armenia',
	'UserCountry_country_an' => 'Netherlands Antilles',
	'UserCountry_country_ao' => 'Angola',
	'UserCountry_country_aq' => 'Antarctica',
	'UserCountry_country_ar' => 'Argentina',
	'UserCountry_country_as' => 'American Samoa',
	'UserCountry_country_at' => 'Austria',
	'UserCountry_country_au' => 'Australia',
	'UserCountry_country_aw' => 'Aruba',
	'UserCountry_country_ax' => 'Aland Islands',
	'UserCountry_country_az' => 'Azerbaijan',
	'UserCountry_country_ba' => 'Bosnia and Herzegovina',
	'UserCountry_country_bb' => 'Barbados',
	'UserCountry_country_bd' => 'Bangladesh',
	'UserCountry_country_be' => 'Belgium',
	'UserCountry_country_bf' => 'Burkina Faso',
	'UserCountry_country_bg' => 'Bulgaria',
	'UserCountry_country_bh' => 'Bahrain',
	'UserCountry_country_bi' => 'Burundi',
	'UserCountry_country_bj' => 'Benin',
	'UserCountry_country_bl' => 'Saint Barthelemy',
	'UserCountry_country_bm' => 'Bermuda',
	'UserCountry_country_bn' => 'Bruneo',
	'UserCountry_country_bo' => 'Bolivia',
	'UserCountry_country_br' => 'Brazil',
	'UserCountry_country_bs' => 'Bahamas',
	'UserCountry_country_bt' => 'Bhutan',
	'UserCountry_country_bu' => 'Burma',
	'UserCountry_country_bv' => 'Bouvet Island',
	'UserCountry_country_bw' => 'Botswana',
	'UserCountry_country_by' => 'Belarus',
	'UserCountry_country_bz' => 'Belize',
	'UserCountry_country_ca' => 'Canada',
	'UserCountry_country_cc' => 'Cocos (Keeling) Islands',
	'UserCountry_country_cd' => 'Congo, The Democratic Republic of the',
	'UserCountry_country_cf' => 'Central African Republic',
	'UserCountry_country_cg' => 'Congo',
	'UserCountry_country_ch' => 'Switzerland',
	'UserCountry_country_ci' => 'Cote D\'Ivoire',
	'UserCountry_country_ck' => 'Cook Islands',
	'UserCountry_country_cl' => 'Chile',
	'UserCountry_country_cm' => 'Cameroon',
	'UserCountry_country_cn' => 'China',
	'UserCountry_country_co' => 'Colombia',
	'UserCountry_country_cp' => 'Clipperton Island',
	'UserCountry_country_cr' => 'Costa Rica',
	'UserCountry_country_cs' => 'Serbia Montenegro',
	'UserCountry_country_cu' => 'Cuba',
	'UserCountry_country_cv' => 'Cape Verde',
	'UserCountry_country_cx' => 'Christmas Island',
	'UserCountry_country_cy' => 'Cyprus',
	'UserCountry_country_cz' => 'Czech Republic',
	'UserCountry_country_de' => 'Germany',
	'UserCountry_country_dg' => 'Diego Garcia',
	'UserCountry_country_dj' => 'Djibouti',
	'UserCountry_country_dk' => 'Denmark',
	'UserCountry_country_dm' => 'Dominica',
	'UserCountry_country_do' => 'Dominican Republic',
	'UserCountry_country_dz' => 'Algeria',
	'UserCountry_country_ea' => 'Ceuta, Melilla',
	'UserCountry_country_ec' => 'Ecuador',
	'UserCountry_country_ee' => 'Estonia',
	'UserCountry_country_eg' => 'Egypt',
	'UserCountry_country_eh' => 'Western Sahara',
	'UserCountry_country_er' => 'Eritrea',
	'UserCountry_country_es' => 'Spain',
	'UserCountry_country_et' => 'Ethiopia',
	'UserCountry_country_eu' => 'European Union',
	'UserCountry_country_fi' => 'Finland',
	'UserCountry_country_fj' => 'Fiji',
	'UserCountry_country_fk' => 'Falkland Islands (Malvinas)',
	'UserCountry_country_fm' => 'Micronesia, Federated States of',
	'UserCountry_country_fo' => 'Faroe Islands',
	'UserCountry_country_fr' => 'France',
	'UserCountry_country_fx' => 'France, Metropolitan',
	'UserCountry_country_ga' => 'Gabon',
	'UserCountry_country_gb' => 'Great Britain',
	'UserCountry_country_gd' => 'Grenada',
	'UserCountry_country_ge' => 'Georgia',
	'UserCountry_country_gf' => 'French Guyana',
	'UserCountry_country_gg' => 'Guernsey',
	'UserCountry_country_gh' => 'Ghana',
	'UserCountry_country_gi' => 'Gibraltar',
	'UserCountry_country_gl' => 'Greenland',
	'UserCountry_country_gm' => 'Gambia',
	'UserCountry_country_gn' => 'Guinea',
	'UserCountry_country_gp' => 'Guadeloupe',
	'UserCountry_country_gq' => 'Equatorial Guinea',
	'UserCountry_country_gr' => 'Greece',
	'UserCountry_country_gs' => 'South Georgia and the South Sandwich Islands',
	'UserCountry_country_gt' => 'Guatemala',
	'UserCountry_country_gu' => 'Guam',
	'UserCountry_country_gw' => 'Guinea-Bissau',
	'UserCountry_country_gy' => 'Guyana',
	'UserCountry_country_hk' => 'Hong Kong',
	'UserCountry_country_hm' => 'Heard Island and McDonald Islands',
	'UserCountry_country_hn' => 'Honduras',
	'UserCountry_country_hr' => 'Croatia',
	'UserCountry_country_ht' => 'Haiti',
	'UserCountry_country_hu' => 'Hungary',
	'UserCountry_country_ic' => 'Canary Islands',
	'UserCountry_country_id' => 'Indonesia',
	'UserCountry_country_ie' => 'Ireland',
	'UserCountry_country_il' => 'Israel',
	'UserCountry_country_im' => 'Man Island',
	'UserCountry_country_in' => 'India',
	'UserCountry_country_io' => 'British Indian Ocean Territory',
	'UserCountry_country_iq' => 'Iraq',
	'UserCountry_country_ir' => 'Iran, Islamic Republic of',
	'UserCountry_country_is' => 'Iceland',
	'UserCountry_country_it' => 'Italy',
	'UserCountry_country_je' => 'Jersey',
	'UserCountry_country_jm' => 'Jamaica',
	'UserCountry_country_jo' => 'Jordan',
	'UserCountry_country_jp' => 'Japan',
	'UserCountry_country_ke' => 'Kenya',
	'UserCountry_country_kg' => 'Kyrgyzstan',
	'UserCountry_country_kh' => 'Cambodia',
	'UserCountry_country_ki' => 'Kiribati',
	'UserCountry_country_km' => 'Comoros',
	'UserCountry_country_kn' => 'Saint Kitts and Nevis',
	'UserCountry_country_kp' => 'Korea, Democratic People\'s Republic of',
	'UserCountry_country_kr' => 'Korea, Republic of',
	'UserCountry_country_kw' => 'Kuwait',
	'UserCountry_country_ky' => 'Cayman Islands',
	'UserCountry_country_kz' => 'Kazakhstan',
	'UserCountry_country_la' => 'Laos',
	'UserCountry_country_lb' => 'Lebanon',
	'UserCountry_country_lc' => 'Saint Lucia',
	'UserCountry_country_li' => 'Liechtenstein',
	'UserCountry_country_lk' => 'Sri Lanka',
	'UserCountry_country_lr' => 'Liberia',
	'UserCountry_country_ls' => 'Lesotho',
	'UserCountry_country_lt' => 'Lithuania',
	'UserCountry_country_lu' => 'Luxembourg',
	'UserCountry_country_lv' => 'Latvia',
	'UserCountry_country_ly' => 'Libya',
	'UserCountry_country_ma' => 'Morocco',
	'UserCountry_country_mc' => 'Monaco',
	'UserCountry_country_md' => 'Moldova, Republic of',
	'UserCountry_country_me' => 'Montenegro',
	'UserCountry_country_mf' => 'Saint Martin',
	'UserCountry_country_mg' => 'Madagascar',
	'UserCountry_country_mh' => 'Marshall Islands',
	'UserCountry_country_mk' => 'Macedonia',
	'UserCountry_country_ml' => 'Mali',
	'UserCountry_country_mm' => 'Myanmar',
	'UserCountry_country_mn' => 'Mongolia',
	'UserCountry_country_mo' => 'Macau',
	'UserCountry_country_mp' => 'Northern Mariana Islands',
	'UserCountry_country_mq' => 'Martinique',
	'UserCountry_country_mr' => 'Mauritania',
	'UserCountry_country_ms' => 'Montserrat',
	'UserCountry_country_mt' => 'Malta',
	'UserCountry_country_mu' => 'Mauritius',
	'UserCountry_country_mv' => 'Maldives',
	'UserCountry_country_mw' => 'Malawi',
	'UserCountry_country_mx' => 'Mexico',
	'UserCountry_country_my' => 'Malaysia',
	'UserCountry_country_mz' => 'Mozambique',
	'UserCountry_country_na' => 'Namibia',
	'UserCountry_country_nc' => 'New Caledonia',
	'UserCountry_country_ne' => 'Niger',
	'UserCountry_country_nf' => 'Norfolk Island',
	'UserCountry_country_ng' => 'Nigeria',
	'UserCountry_country_ni' => 'Nicaragua',
	'UserCountry_country_nl' => 'Netherlands',
	'UserCountry_country_no' => 'Norway',
	'UserCountry_country_np' => 'Nepal',
	'UserCountry_country_nr' => 'Nauru',
	'UserCountry_country_nt' => 'Neutral Zone',
	'UserCountry_country_nu' => 'Niue',
	'UserCountry_country_nz' => 'New Zealand',
	'UserCountry_country_om' => 'Oman',
	'UserCountry_country_pa' => 'Panama',
	'UserCountry_country_pe' => 'Peru',
	'UserCountry_country_pf' => 'French Polynesia',
	'UserCountry_country_pg' => 'Papua New Guinea',
	'UserCountry_country_ph' => 'Philippines',
	'UserCountry_country_pk' => 'Pakistan',
	'UserCountry_country_pl' => 'Poland',
	'UserCountry_country_pm' => 'Saint Pierre and Miquelon',
	'UserCountry_country_pn' => 'Pitcairn',
	'UserCountry_country_pr' => 'Puerto Rico',
	'UserCountry_country_ps' => 'Palestinian Territory',
	'UserCountry_country_pt' => 'Portugal',
	'UserCountry_country_pw' => 'Palau',
	'UserCountry_country_py' => 'Paraguay',
	'UserCountry_country_qa' => 'Qatar',
	'UserCountry_country_re' => 'Reunion Island',
	'UserCountry_country_ro' => 'Romania',
	'UserCountry_country_rs' => 'Serbia',
	'UserCountry_country_ru' => 'Russia',
	'UserCountry_country_rw' => 'Rwanda',
	'UserCountry_country_sa' => 'Saudi Arabia',
	'UserCountry_country_sb' => 'Solomon Islands',
	'UserCountry_country_sc' => 'Seychelles',
	'UserCountry_country_sd' => 'Sudan',
	'UserCountry_country_se' => 'Sweden',
	'UserCountry_country_sf' => 'Finland',
	'UserCountry_country_sg' => 'Singapore',
	'UserCountry_country_sh' => 'Saint Helena',
	'UserCountry_country_si' => 'Slovenia',
	'UserCountry_country_sj' => 'Svalbard',
	'UserCountry_country_sk' => 'Slovakia',
	'UserCountry_country_sl' => 'Sierra Leone',
	'UserCountry_country_sm' => 'San Marino',
	'UserCountry_country_sn' => 'Senegal',
	'UserCountry_country_so' => 'Somalia',
	'UserCountry_country_sr' => 'Suriname',
	'UserCountry_country_st' => 'Sao Tome and Principe',
	'UserCountry_country_su' => 'Old U.S.S.R',
	'UserCountry_country_sv' => 'El Salvador',
	'UserCountry_country_sy' => 'Syrian Arab Republic',
	'UserCountry_country_sz' => 'Swaziland',
	'UserCountry_country_ta' => 'Tristan da Cunha',
	'UserCountry_country_tc' => 'Turks and Caicos Islands',
	'UserCountry_country_td' => 'Chad',
	'UserCountry_country_tf' => 'French Southern Territories',
	'UserCountry_country_tg' => 'Togo',
	'UserCountry_country_th' => 'Thailand',
	'UserCountry_country_tj' => 'Tajikistan',
	'UserCountry_country_tk' => 'Tokelau',
	'UserCountry_country_tl' => 'East Timor',
	'UserCountry_country_tm' => 'Turkmenistan',
	'UserCountry_country_tn' => 'Tunisia',
	'UserCountry_country_to' => 'Tonga',
	'UserCountry_country_tp' => 'East Timor',
	'UserCountry_country_tr' => 'Turkey',
	'UserCountry_country_tt' => 'Trinidad and Tobago',
	'UserCountry_country_tv' => 'Tuvalu',
	'UserCountry_country_tw' => 'Taiwan',
	'UserCountry_country_tz' => 'Tanzania, United Republic of',
	'UserCountry_country_ua' => 'Ukraine',
	'UserCountry_country_ug' => 'Uganda',
	'UserCountry_country_uk' => 'United Kingdom',
	'UserCountry_country_um' => 'United States Minor Outlying Islands',
	'UserCountry_country_us' => 'United States',
	'UserCountry_country_uy' => 'Uruguay',
	'UserCountry_country_uz' => 'Uzbekistan',
	'UserCountry_country_va' => 'Vatican City',
	'UserCountry_country_vc' => 'Saint Vincent and the Grenadines',
	'UserCountry_country_ve' => 'Venezuela',
	'UserCountry_country_vg' => 'Virgin Islands, British',
	'UserCountry_country_vi' => 'Virgin Islands, U.S.',
	'UserCountry_country_vn' => 'Vietnam',
	'UserCountry_country_vu' => 'Vanuatu',
	'UserCountry_country_wf' => 'Wallis and Futuna',
	'UserCountry_country_ws' => 'Samoa',
	'UserCountry_country_ye' => 'Yemen',
	'UserCountry_country_yt' => 'Mayotte',
	'UserCountry_country_yu' => 'Yugoslavia',
	'UserCountry_country_za' => 'South Africa',
	'UserCountry_country_zm' => 'Zambia',
	'UserCountry_country_zr' => 'Zaire',
	'UserCountry_country_zw' => 'Zimbabwe',
	'UserCountry_continent_eur' => 'Evropa',
	'UserCountry_continent_afr' => 'Afrika',
	'UserCountry_continent_asi' => 'Asie',
	'UserCountry_continent_amn' => 'Jižní Amerika',
	'UserCountry_continent_ams' => 'Severní a střední Amerika',
	'UserCountry_continent_oce' => 'Oceanie',
	'UserCountryMap_map' => 'mapa',
	'UserCountryMap_worldMap' => 'mapa světa',
	'UserCountryMap_toggleFullscreen' => 'Přepnout celou obrazovku',
	'UserSettings_PluginDescription' => 'Zobrazí různá uživatelská nastavení: prohlížeč, rodinu prohlížečů, operační systém, pluginy, rozlišení, globální nastavení.',
	'UserSettings_VisitorSettings' => 'Nastavení návštěvníků',
	'UserSettings_BrowserFamilies' => 'Rodiny Web prohlížečů',
	'UserSettings_Browsers' => 'Web prohlížeče',
	'UserSettings_Plugins' => 'Pluginy',
	'UserSettings_Configurations' => 'Nastavení',
	'UserSettings_OperatingSystems' => 'Operační systémy',
	'UserSettings_Resolutions' => 'Rozlišení',
	'UserSettings_WideScreen' => 'Širokoúhlá obrazovka',
	'UserSettings_ColumnBrowserFamily' => 'Rodina Web prohlížeče',
	'UserSettings_ColumnBrowser' => 'Web prohlížeč',
	'UserSettings_ColumnPlugin' => 'Plugin',
	'UserSettings_ColumnConfiguration' => 'Konfigurace',
	'UserSettings_ColumnOperatingSystem' => 'Operační systém',
	'UserSettings_ColumnResolution' => 'Rozlišení',
	'UserSettings_ColumnTypeOfScreen' => 'Typ obrazovky',
	'UserSettings_WidgetResolutions' => 'Rozlišení obrazovky',
	'UserSettings_WidgetBrowsers' => 'Web prohlížeče návštěvníků',
	'UserSettings_WidgetPlugins' => 'Seznam pluginů',
	'UserSettings_PluginDetectionDoesNotWorkInIE' => 'Poznámka: Detekce pluginů nepracuje v prohlížeči Interet Explorer. Toto hlášení je založeno na ostatních prohlížečích',
	'UserSettings_WidgetWidescreen' => 'Normální / Širokoúhlá',
	'UserSettings_WidgetBrowserFamilies' => 'Prohlížeče podle rodiny',
	'UserSettings_WidgetOperatingSystems' => 'Operační systémy',
	'UserSettings_WidgetGlobalVisitors' => 'Hlavní nastavení návštěvníků',
	'UserSettings_SubmenuSettings' => 'Nastavení',
	'UsersManager_PluginDescription' => 'Správa uživatelů v Piwiku: přidat nového uživatele, upravit existujícícho, aktualizace oprávnění. Všechny akce jsou k dizpozici přes API',
	'UsersManager_UsersManagement' => 'Správa uživatelů',
	'UsersManager_UsersManagementMainDescription' => 'Vytvořte nové uživatele, nebo aktualizujte existující. Níže můžete nastavit jejich oprávnění.',
	'UsersManager_ManageAccess' => 'Správa přístupu',
	'UsersManager_MainDescription' => 'Nastavení, kteří uživatelé mají přístup k Piwik statistikám na vaších stránkách. Můžete také nastavit oprávnění ke všem stránkám najednou.',
	'UsersManager_Sites' => 'Web sídla',
	'UsersManager_AllWebsites' => 'Všechny Web sídla',
	'UsersManager_ApplyToAllWebsites' => 'Použít na všechny Web sídla',
	'UsersManager_User' => 'Uživatel',
	'UsersManager_PrivNone' => 'Žádné oprávnění',
	'UsersManager_PrivView' => 'Zobrazení',
	'UsersManager_PrivAdmin' => 'Administrátor',
	'UsersManager_ChangeAllConfirm' => 'Jste si jistí, že chcte změnit \'%s\' oprávnění pro všechny web sídla?',
	'UsersManager_Password' => 'Heslo',
	'UsersManager_Email' => 'E-mail',
	'UsersManager_Alias' => 'Alias',
	'UsersManager_TheSuperUserAliasCannotBeChanged' => 'Alias super uživatele nemůže být změněn',
	'UsersManager_ReportToLoadByDefault' => 'Hlášení, které se má načíst jako výchozí',
	'UsersManager_ReportDateToLoadByDefault' => 'Datum hlášení, které se má načíst jako výchozí',
	'UsersManager_ForAnonymousUsersReportDateToLoadByDefault' => 'Datum hlášení, které se má načíst jako výchozí pro anonymní uživatele',
	'UsersManager_ExcludeVisitsViaCookie' => 'Vynechat vaše navštěvy pomocí cookie',
	'UsersManager_YourVisitsAreIgnoredOnDomain' => '%sVaše návštěvy jsou vynechávány Piwikem na %s %s (cookie pro vynechání byla nalezena ve vašem prohlížeči).',
	'UsersManager_YourVisitsAreNotIgnored' => '%sVaše návštěvy nejsou vynechávány Piwikem%s (cookie pro vynechání nebyla nalezena ve vašem prohlížeči).',
	'UsersManager_ClickHereToDeleteTheCookie' => 'Klinětě zde pro vymazání cookie a zaznamenávání vaších návštěv',
	'UsersManager_ClickHereToSetTheCookieOnDomain' => 'Klikněte zde pro nastavení cookie, která vynechá vaše návštěvy na sídlech monitorováných Piwikem na %s',
	'UsersManager_Edit' => 'Upravit',
	'UsersManager_AddUser' => 'Přidat nového uživatele',
	'UsersManager_MenuUsers' => 'Uživatelé',
	'UsersManager_MenuUserSettings' => 'Nastavení uživatele',
	'UsersManager_MenuAnonymousUserSettings' => 'Nastavení anonymního uživatele',
	'UsersManager_NoteNoAnonymousUserAccessSettingsWontBeUsed' => 'Poznámka: Nemáte nastaveno žádné sídlo pro přístup anonymních uživatelů, následující nastaveni nebudou použita.',
	'UsersManager_WhenUsersAreNotLoggedInAndVisitPiwikTheyShouldAccess' => 'Když uživatelé nejsou přihlášení do Piwiku, můžou mít přístup k',
	'UsersManager_ChangePassword' => 'Změnit heslo',
	'UsersManager_IfYouWouldLikeToChangeThePasswordTypeANewOne' => 'Pokud chcete změnit heslo, zapiště jej. Jinak jej nevyplňujte.',
	'UsersManager_TypeYourPasswordAgain' => 'Zapiště vaše nové heslo znova',
	'UsersManager_TheLoginScreen' => 'Přihlašovací obrazovka',
	'UsersManager_DeleteConfirm_js' => 'Jste si jistí, že chcete vymazat uživatele %s?',
	'UsersManager_YourUsernameCannotBeChanged' => 'Vaše uživatelské jméno nemůže být změněno',
	'UsersManager_ExceptionLoginExists' => 'Uživatelské jméno \'%s\' již existuje.',
	'UsersManager_ExceptionEmailExists' => 'Uživatel s emailem \'%s\' již existuje.',
	'UsersManager_ExceptionInvalidLoginFormat' => 'Přihlašovací jméno musí obsahovat mezi %s a %s znaky a obsahovat pouze písmena, čísla, nebo znaky \'_\' nebo \'-\' nebo \'.\'',
	'UsersManager_ExceptionInvalidEmail' => 'Email nemá platný formát.',
	'UsersManager_ExceptionDeleteDoesNotExist' => 'Uživatel \'%s\' neexistuje a proto nemůže být vymazán.',
	'UsersManager_ExceptionAdminAnonymous' => 'Nemůžete dát \'admin\' přístup \'anonymous\' uživateli.',
	'UsersManager_ExceptionEditAnonymous' => '\'Anonymous\' uživatel nemůže být upraven, nebo vymazán. Je použit Piwikem k definici uživatele, který ještě není přihlášen. Například můžete zveřejnit vaše statistiky udělením oprávnění \'view\' uživateli \'anonymous\'.',
	'UsersManager_ExceptionSuperUser' => 'Požadovaný uživatel je \'Super uživatel\' a nemůže být dotazován, upravován, nebo mazán pomocí API. Musíte jej ručně upravit v konfiguračním souboru Piwik..',
	'UsersManager_ExceptionUserDoesNotExist' => 'Uživatel \'%s\' neexistuje.',
	'UsersManager_ExceptionAccessValues' => 'Parametr přístupu musí mít jednu z následujících hodnot : [ %s ]',
	'UsersManager_ExceptionPasswordMD5HashExpected' => 'UsersManager.getTokenAuth očekává heslo v podobě MD5 hashe (32 znaků dlouhého řetězce). Prosím nejprve zavoltejte metodu md5() na tomto hesle.',
	'VisitFrequency_PluginDescription' => 'Hlásí různé statistiky o navracejících se versus nových návštěvnících',
	'VisitFrequency_Evolution' => 'Vývoj za periodu',
	'VisitFrequency_ColumnReturningVisits' => 'Opětovných návštěv',
	'VisitFrequency_ColumnActionsByReturningVisits' => 'Akcí za opakovanou návštěvu',
	'VisitFrequency_ColumnAverageVisitDurationForReturningVisitors' => 'Průměrná délka návštěvy pro navracejících se návštěvnících (v sekundách)',
	'VisitFrequency_ColumnBounceRateForReturningVisits' => 'Frekvence odchodů pro opakované návštěvy',
	'VisitFrequency_ColumnAvgActionsPerReturningVisit' => 'Proměrnů počet akcí pro navracející se návštěvníky',
	'VisitFrequency_ReturnVisits' => '%s opakujících se návštěv',
	'VisitFrequency_ReturnActions' => '%s akcí za opakovanou návštěvu',
	'VisitFrequency_ReturnAvgActions' => '%s akcí na navracejících se návštěvníka',
	'VisitFrequency_ReturnAverageVisitDuration' => '%s průměrná dělka návštěvy pro navracející se návštěvníky',
	'VisitFrequency_ReturnBounceRate' => '%s opakujících se návštěv odešlo (opustilo sídlo po jedné stránce)',
	'VisitFrequency_WidgetOverview' => 'Přehled frekvencí',
	'VisitFrequency_WidgetGraphReturning' => 'Graf opakujících se návštěv',
	'VisitFrequency_SubmenuFrequency' => 'Frekvence',
	'VisitorGenerator_PluginDescription' => 'Plugin pro vytvoření falešných návštěv. Může být použit vývojaři, nebo uživateli Piwiku jako jednoduchá cesta k vygenerování testovacích návštěv k naplnění hlášení Piwiku.',
	'VisitorGenerator_VisitorGenerator' => 'Generátor návštěv',
	'VisitorGenerator_Warning' => 'Chystáte se vygenerovat falešné návštěvy, které budou zaznamenány do vaší databáze Piwiku',
	'VisitorGenerator_NotReversible' => 'Tyto návštěvy %s nebude%s možné jednoduše vymazat z logů Piwiku',
	'VisitorGenerator_AreYouSure' => 'Jste si jistý, že chcete vygenerovat falešné návštěvy',
	'VisitorGenerator_ChoiceYes' => 'Ano, jsem si jistý',
	'VisitorGenerator_Submit' => 'Odeslat',
	'VisitorGenerator_SelectWebsite' => 'Zvolte sídlo',
	'VisitorGenerator_NbRequestsPerSec' => 'Požadavků za sekundu',
	'VisitorGenerator_DaysToCompute' => 'Dní na výpočet',
	'VisitorInterest_PluginDescription' => 'Hlášení o zájmů návštěvníků: počet otevřených stránek, čas strávený na sídle',
	'VisitorInterest_VisitsPerDuration' => 'Návštěv za dobu návštěvy',
	'VisitorInterest_VisitsPerNbOfPages' => 'Návštěv za počet stránek',
	'VisitorInterest_ColumnVisitDuration' => 'Doba návštěvy',
	'VisitorInterest_ColumnPagesPerVisit' => 'Stránek za návštěvu',
	'VisitorInterest_WidgetLengths' => 'Doba návštěv',
	'VisitorInterest_WidgetPages' => 'Stránek za návštěvu',
	'VisitorInterest_Engagement' => 'Závazek',
	'VisitorInterest_PlusXMin' => '%s min',
	'VisitorInterest_BetweenXYMinutes' => '%1$s-%2$s minut',
	'VisitorInterest_OnePage' => '1 stránka',
	'VisitorInterest_NPages' => '%s stránek',
	'VisitorInterest_BetweenXYSeconds' => '%1$s-%2$ss',
	'VisitsSummary_PluginDescription' => 'Hlásí základní analytická čísla: návštěv, unikátních návštěvníků, počet akcí, poměr návratů',
	'VisitsSummary_VisitsSummary' => 'Shrnutí návštěv',
	'VisitsSummary_NbVisits' => '%s návštěv',
	'VisitsSummary_NbUniqueVisitors' => '%s unikátních návštěvníků',
	'VisitsSummary_NbActionsDescription' => '%s akcí (zobrazení stránek, stažení a odchodů)',
	'VisitsSummary_AverageVisitDuration' => '%s průměrná doba návštěvy',
	'VisitsSummary_MaxNbActions' => '%s maximální počet akcí na návštěvu',
	'VisitsSummary_NbActionsPerVisit' => '%s akcí za návštěvu',
	'VisitsSummary_NbVisitsBounced' => '%s návštěvníků odešlo (opustilo sídlo po jedné stránce)',
	'VisitsSummary_EvolutionOverLastPeriods' => 'Vývoj za poslední %s',
	'VisitsSummary_GenerateTime' => '%s sekund k vygenerování stránky',
	'VisitsSummary_GenerateQueries' => '%s provedeno dotazů',
	'VisitsSummary_WidgetLastVisits' => 'Graf posledních návštěv',
	'VisitsSummary_WidgetVisits' => 'Přehled návštěv',
	'VisitsSummary_WidgetLastVisitors' => 'Graf posledních jedinečných návštěvníků',
	'VisitsSummary_WidgetOverviewGraph' => 'Přehled s grafem',
	'VisitsSummary_SubmenuOverview' => 'Přehled',
	'VisitTime_PluginDescription' => 'Hlásí lokální a serverový čas. Informace o serverovém času je užitečná pro naplánování odstávky sídla',
	'VisitTime_LocalTime' => 'Návštěvy podle lokálního času',
	'VisitTime_ServerTime' => 'Návštěvy podle serverového času',
	'VisitTime_ColumnServerTime' => 'Serverový čas',
	'VisitTime_ColumnLocalTime' => 'Lokální čas',
	'VisitTime_WidgetLocalTime' => 'Návštěvy podle lokálního času',
	'VisitTime_WidgetServerTime' => 'Návštěvy podle serverového času',
	'VisitTime_SubmenuTimes' => 'Časy',
	'VisitTime_NHour' => '%sh',
	'Widgetize_PluginDescription' => 'Tento plugin zjednodušuje export widgetů Piwiku na váš blog, sídlo nebo Igoogle a Netvibes!',
	'PDFReports_EmailReports' => 'Poslat reporty na e-mail',
	'PDFReports_PDF' => 'PDF',
	'PDFReports_SendReportNow' => 'Odeslat report ihned',
	'PDFReports_EmailSchedule' => 'Plánování zasílání reportů',
	'PDFReports_SendReportTo' => 'Odeslat report',
	'PDFReports_SentToMe' => 'Odeslat report mně',
	'PDFReports_WeeklyScheduleHelp' => 'Týdenní plán: hlášení bude odesláno každé pondělí',
	'PDFReports_MonthlyScheduleHelp' => 'Měsíční plán: hlášení bude odesláno první den měsíce',
	'PDFReports_AlsoSendReportToTheseEmails' => 'Odesílat hlášení také na tyto e-maily (jeden e-mail na řádek):',
	'PDFReports_PiwikReports' => 'Hlášení Piwiku',
	'PDFReports_EmailHello' => 'Ahoj,',
	'PDFReports_PleaseFindAttachedFile' => 'Prosím najděte v přiloženém souboru %1$s hlášení pro %2$s',
	'PDFReports_FrontPage' => 'Hlavní strana',
	'PDFReports_TopOfReport' => 'Zpět nahoru',
	'PDFReports_Pagination' => 'Stránka %s z %s',
);
